# semi-colon
semi-colon is a utility package for CV, data science, Machine Learning and Deep Learning.
## functions
* `semi_colon.imshows(imgs, rows=1, cols=None, bgr=True, figsize=None, axis=False)`
* `semi_colon.download(url, dir=None, file_name=None, extract=False)`
* `semi_colon.digit_split(image, size=None, flatten=False, border=0, inverse=True)`
* `semi_colon.load_boston()`
* `semi_colon.colab.imMouseCallback(imgs, onmouse=None)`